@@ -9,10 +9,11 @@ import html
 import collections
 import functools
 import dataclasses
-from typing import Deque, MutableSequence, Optional, cast
+from typing import Optional, cast
+from collections.abc import MutableSequence
 
 from qutebrowser.qt.core import (pyqtSlot, pyqtSignal, Qt, QTimer, QDir, QModelIndex,
-                          QItemSelectionModel, QObject, QEventLoop)
+                          QItemSelectionModel, QObject, QEventLoop, QUrl)
 from qutebrowser.qt.widgets import (QWidget, QGridLayout, QVBoxLayout, QLineEdit,
                              QLabel, QTreeView, QSizePolicy,
                              QSpacerItem, QFileIconProvider)
@@ -23,7 +24,7 @@ from qutebrowser.config import config, configtypes, configexc, stylesheet
 from qutebrowser.utils import usertypes, log, utils, qtutils, objreg, message
 from qutebrowser.keyinput import modeman
 from qutebrowser.api import cmdutils
-from qutebrowser.utils import urlmatch
+from qutebrowser.utils import urlmatch, urlutils
 
 
 prompt_queue = cast('PromptQueue', None)
@@ -89,7 +90,7 @@ class PromptQueue(QObject):
         self._question = None
         self._shutting_down = False
         self._loops: MutableSequence[qtutils.EventLoop] = []
-        self._queue: Deque[usertypes.Question] = collections.deque()
+        self._queue: collections.deque[usertypes.Question] = collections.deque()
         message.global_bridge.mode_left.connect(self._on_mode_left)
 
     def __repr__(self):
@@ -452,8 +453,9 @@ class PromptContainer(QWidget):
         else:
             sel = False
             target = 'clipboard'
-        utils.set_clipboard(question.url, sel)
-        message.info("Yanked to {}: {}".format(target, question.url))
+        url_str = urlutils.get_url_yank_text(QUrl(question.url), pretty=False)
+        utils.set_clipboard(url_str, sel)
+        message.info("Yanked to {}: {}".format(target, url_str))
 
     @cmdutils.register(
         instance='prompt-container', scope='window',
@@ -975,12 +977,22 @@ class YesNoPrompt(_BasePrompt):
             raise Error("Invalid value {} - expected yes/no!".format(value))
 
         if save:
+            value = self.question.answer
             opt = config.instance.get_opt(self.question.option)
-            assert isinstance(opt.typ, configtypes.Bool)
+            if isinstance(opt.typ, configtypes.Bool):
+                pass
+            elif isinstance(opt.typ, configtypes.AsBool):
+                value = opt.typ.from_bool(value)
+            else:
+                raise AssertionError(
+                    f"Cannot save prompt answer ({opt.name}). Expected 'Bool' or 'AsBool' "
+                    f"type option, got: value={value} type={type(opt.typ)}"
+                )
+
             pattern = urlmatch.UrlPattern(self.question.url)
 
             try:
-                config.instance.set_obj(opt.name, self.question.answer,
+                config.instance.set_obj(opt.name, value,
                                         pattern=pattern, save_yaml=True)
             except configexc.Error as e:
                 raise Error(str(e))
